pynrc.reduce.calib.nircam\_cal
==============================

.. currentmodule:: pynrc.reduce.calib

.. autoclass:: nircam_cal
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~nircam_cal.__init__
      ~nircam_cal.calc_cds_noise
      ~nircam_cal.deconvolve_supers
      ~nircam_cal.get_cds_dict
      ~nircam_cal.get_column_variations
      ~nircam_cal.get_dark_slope_image
      ~nircam_cal.get_effective_noise
      ~nircam_cal.get_ipc
      ~nircam_cal.get_ktc_noise
      ~nircam_cal.get_linear_coeffs
      ~nircam_cal.get_nonlinear_coeffs
      ~nircam_cal.get_pixel_slope_averages
      ~nircam_cal.get_power_spectrum
      ~nircam_cal.get_ref_pixel_noise
      ~nircam_cal.get_super_bias_init
      ~nircam_cal.get_super_bias_update
      ~nircam_cal.get_super_dark_ramp
      ~nircam_cal.get_super_flats
      ~nircam_cal.plot_bias_darks
      ~nircam_cal.plot_cds_noise
      ~nircam_cal.plot_dark_distribution
      ~nircam_cal.plot_dark_overview
      ~nircam_cal.plot_dark_ramps
      ~nircam_cal.plot_dark_ramps_ch
      ~nircam_cal.plot_eff_noise
      ~nircam_cal.plot_eff_noise_patterns
      ~nircam_cal.plot_ipc_ppc
      ~nircam_cal.plot_power_spectrum
      ~nircam_cal.plot_reset_overview
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~nircam_cal.allfiles
      ~nircam_cal.cds_act_dict
      ~nircam_cal.cds_ref_dict
      ~nircam_cal.chsize
      ~nircam_cal.column_prob_bad
      ~nircam_cal.column_variations
      ~nircam_cal.dark_ramp_dict
      ~nircam_cal.dark_shape
      ~nircam_cal.datadir
      ~nircam_cal.eff_noise_dict
      ~nircam_cal.ipc_alpha_frac
      ~nircam_cal.kernel_ipc
      ~nircam_cal.kernel_ppc
      ~nircam_cal.ktc_noise
      ~nircam_cal.lindir
      ~nircam_cal.linfiles
      ~nircam_cal.mask_act
      ~nircam_cal.mask_channels
      ~nircam_cal.mask_ref
      ~nircam_cal.nchan
      ~nircam_cal.nchans
      ~nircam_cal.outdir
      ~nircam_cal.pow_spec_dict
      ~nircam_cal.ppc_frac
      ~nircam_cal.ref_pixel_dict
      ~nircam_cal.super_bias
      ~nircam_cal.super_bias_deconv
      ~nircam_cal.super_dark
      ~nircam_cal.super_dark_deconv
      ~nircam_cal.super_dark_ramp
      ~nircam_cal.temperature_dict
      ~nircam_cal.time_arr
   
   